==> jc-1.4.0.tar.gz: javax/crypto/spec/SecretKeySpec.h <==
// public class javax.crypto.spec.SecretKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 509d062f9c8cb51b javax_crypto_spec_SecretKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_SecretKeySpec_H_
#define _JC_javax_crypto_spec_SecretKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_SecretKeySpec$sub_refs	_jc_javax_crypto_spec_SecretKeySpec$sub_refs;
typedef struct _jc_javax_crypto_spec_SecretKeySpec$sub_nonrefs	_jc_javax_crypto_spec_SecretKeySpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_SecretKeySpec$refs	_jc_javax_crypto_spec_SecretKeySpec$refs;
typedef struct _jc_javax_crypto_spec_SecretKeySpec$nonrefs	_jc_javax_crypto_spec_SecretKeySpec$nonrefs;
typedef struct _jc_javax_crypto_spec_SecretKeySpec$object	_jc_javax_crypto_spec_SecretKeySpec$object;

typedef struct _jc_javax_crypto_spec_SecretKeySpec$fields_struct	_jc_javax_crypto_spec_SecretKeySpec$fields_struct;
typedef const struct _jc_javax_crypto_spec_SecretKeySpec$vmethods	_jc_javax_crypto_spec_SecretKeySpec$vmethods;
typedef const struct _jc_javax_crypto_spec_SecretKeySpec$vtable	_jc_javax_crypto_spec_SecretKeySpec$vtable;
typedef const struct _jc_javax_crypto_spec_SecretKeySpec$vtype	_jc_javax_crypto_spec_SecretKeySpec$vtype;

// Class fields structure
struct _jc_javax_crypto_spec_SecretKeySpec$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_crypto_spec_SecretKeySpec$fields_struct _jc_javax_crypto_spec_SecretKeySpec$class_fields;

// Constructors
extern void _jc_javax_crypto_spec_SecretKeySpec$method$_init$ff95abd741397020(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *, struct _jc_byte_array *, jint, jint, struct _jc_java_lang_String$object *);
extern void _jc_javax_crypto_spec_SecretKeySpec$method$_init$44283974efba830c(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *, struct _jc_byte_array *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_javax_crypto_spec_SecretKeySpec$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_javax_crypto_spec_SecretKeySpec$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *);
extern _jc_byte_array *_jc_javax_crypto_spec_SecretKeySpec$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *);
extern struct _jc_java_lang_String$object *_jc_javax_crypto_spec_SecretKeySpec$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *);
extern jint _jc_javax_crypto_spec_SecretKeySpec$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_SecretKeySpec$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_crypto_spec_SecretKeySpec$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_javax_crypto_spec_SecretKeySpec$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_javax_crypto_spec_SecretKeySpec$method_info$getFormat$10e2c7b1e3bfcc3b;
extern _jc_method _jc_javax_crypto_spec_SecretKeySpec$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_javax_crypto_spec_SecretKeySpec$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *);
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *);
	struct _jc_java_lang_String$object	*(*getFormat$10e2c7b1e3bfcc3b)(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *);
};

// Vtable
struct _jc_javax_crypto_spec_SecretKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_SecretKeySpec$vmethods	javax_crypto_spec_SecretKeySpec;
};

// Vtype
struct _jc_javax_crypto_spec_SecretKeySpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_SecretKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_SecretKeySpec$sub_refs {
	_jc_byte_array	*key;
	struct _jc_java_lang_String$object	*algorithm;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_SecretKeySpec$refs {
    _jc_javax_crypto_spec_SecretKeySpec$sub_refs	javax_crypto_spec_SecretKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_SecretKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_SecretKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_SecretKeySpec$sub_nonrefs	javax_crypto_spec_SecretKeySpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_SecretKeySpec$object {
	_jc_javax_crypto_spec_SecretKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_SecretKeySpec$vtype	*vtype;
	_jc_javax_crypto_spec_SecretKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_SecretKeySpec$vtype _jc_javax_crypto_spec_SecretKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_SecretKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_SecretKeySpec$class_object;

#endif	/* _JC_javax_crypto_spec_SecretKeySpec_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/spec/SecretKeySpec.h <==
// public class javax.crypto.spec.SecretKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 509d062f9c8cb51b javax_crypto_spec_SecretKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_SecretKeySpec_H_
#define _JC_javax_crypto_spec_SecretKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_SecretKeySpec$sub_refs	_jc_javax_crypto_spec_SecretKeySpec$sub_refs;
typedef struct _jc_javax_crypto_spec_SecretKeySpec$sub_nonrefs	_jc_javax_crypto_spec_SecretKeySpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_SecretKeySpec$refs	_jc_javax_crypto_spec_SecretKeySpec$refs;
typedef struct _jc_javax_crypto_spec_SecretKeySpec$nonrefs	_jc_javax_crypto_spec_SecretKeySpec$nonrefs;
typedef struct _jc_javax_crypto_spec_SecretKeySpec$object	_jc_javax_crypto_spec_SecretKeySpec$object;

typedef struct _jc_javax_crypto_spec_SecretKeySpec$fields_struct	_jc_javax_crypto_spec_SecretKeySpec$fields_struct;
typedef const struct _jc_javax_crypto_spec_SecretKeySpec$vmethods	_jc_javax_crypto_spec_SecretKeySpec$vmethods;
typedef const struct _jc_javax_crypto_spec_SecretKeySpec$vtable	_jc_javax_crypto_spec_SecretKeySpec$vtable;
typedef const struct _jc_javax_crypto_spec_SecretKeySpec$vtype	_jc_javax_crypto_spec_SecretKeySpec$vtype;

// Class fields structure
struct _jc_javax_crypto_spec_SecretKeySpec$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_crypto_spec_SecretKeySpec$fields_struct _jc_javax_crypto_spec_SecretKeySpec$class_fields;

// Constructors
extern void _jc_javax_crypto_spec_SecretKeySpec$method$_init$ff95abd741397020(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *, struct _jc_byte_array *, jint, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_spec_SecretKeySpec$method$_init$44283974efba830c(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *, struct _jc_byte_array *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_crypto_spec_SecretKeySpec$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_crypto_spec_SecretKeySpec$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_javax_crypto_spec_SecretKeySpec$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_crypto_spec_SecretKeySpec$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_spec_SecretKeySpec$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_SecretKeySpec$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_crypto_spec_SecretKeySpec$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_javax_crypto_spec_SecretKeySpec$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_javax_crypto_spec_SecretKeySpec$method_info$getFormat$10e2c7b1e3bfcc3b;
extern _jc_method _jc_javax_crypto_spec_SecretKeySpec$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_javax_crypto_spec_SecretKeySpec$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getFormat$10e2c7b1e3bfcc3b)(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_crypto_spec_SecretKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_spec_SecretKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_SecretKeySpec$vmethods	javax_crypto_spec_SecretKeySpec;
};

// Vtype
struct _jc_javax_crypto_spec_SecretKeySpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_SecretKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_SecretKeySpec$sub_refs {
	_jc_byte_array	*key;
	struct _jc_java_lang_String$object	*algorithm;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_SecretKeySpec$refs {
    _jc_javax_crypto_spec_SecretKeySpec$sub_refs	javax_crypto_spec_SecretKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_SecretKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_SecretKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_SecretKeySpec$sub_nonrefs	javax_crypto_spec_SecretKeySpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_SecretKeySpec$object {
	_jc_javax_crypto_spec_SecretKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_SecretKeySpec$vtype	*vtype;
	_jc_javax_crypto_spec_SecretKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_SecretKeySpec$vtype _jc_javax_crypto_spec_SecretKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_SecretKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_SecretKeySpec$class_object;

#endif	/* _JC_javax_crypto_spec_SecretKeySpec_H_ */
